@@ -231,8 +231,8 @@ my $configure_php=sub {
    }
    ($stdout,$stderr)=$handle->cwd('/opt/source');
    ($stdout,$stderr)=$handle->cmd($sudo.
-      'wget --no-check-certificate -qO- http://xmlsoft.org/news.html');
-   $stdout=~s/^.*?public releases.*?v(.*?):.*$/$1/s;
+      'wget --no-check-certificate -qO- https://en.wikipedia.org/wiki/Libxml2');
+   $stdout=~s/^.*?Stable release.*?-data["][>](.*?) *[(].*$/$1/s;
    my $lxmlver=$stdout;
    ($stdout,$stderr)=$handle->cmd($sudo.
       "ls -1 /usr/local/lib | grep libxml2.so.$lxmlver");
